package com.me.pacman.entity;

import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.me.pacman.level.LevelTile;
import com.me.pacman.state.PlayState;

public class Pacman extends MovableEntity {

    private TextureRegion[][] sprite;

    private PlayState state;
    private int counter = 1;

    private int freezeFrames = 0;

    public Pacman(PlayState state) {
        super(state, 14, 7.5f, 7.5f, true, Direction.EAST, 0.3f);
        this.state = state;
        sprite = state.getGame().assets.pacman;
    }

    @Override
    public TextureRegion getSprite() {
        int spriteDir;
        switch(currDirection) {
            case NORTH:
                spriteDir = 0;
                break;
            case SOUTH:
                spriteDir = 1;
                break;
            case WEST:
                spriteDir = 2;
                break;
            default:
                spriteDir = 3;
                break;
        }
        return sprite[spriteDir][canMove && moving? counter % 3 : 1];
    }

    @Override
    public void update(float dt) {
        if (freezeFrames > 0) {
            freezeFrames--;
            return;
        }

        super.update(dt);

        if (!state.paused && canMove && age % 4 == 0) {
            counter += 1;
        }

        switch (state.level.getTile(x, y)) {
            case PELLET:
                state.eatPellet(x, y);
                freezeFrames = 1;
                break;
        }
    }

}
