package com.me.pacman.state;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.InputAdapter;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.me.pacman.PacDude;
import com.me.pacman.entity.MovableEntity;
import com.me.pacman.entity.Pacman;
import com.me.pacman.level.Level;
import com.me.pacman.level.LevelTile;

public class PlayState extends LevelState {

    private Texture levelBackground;
    private BitmapFont font;

    private int pelletCount = 0;
    private int pelletEatenCount = 0;
    private int score = 0;

    public boolean paused = false;

    private Pacman pacman;

    public PlayState(PacDude game) {
        super(game);
    }

    @Override
    public void setup() {
        levelBackground = game.assets.getLevelBackground();
        font = game.assets.getFont();

        level = new Level(game,"level");
        pelletCount = level.getTileCount(LevelTile.PELLET);

        pacman = new Pacman(this);

        Gdx.input.setInputProcessor(new Controller());
    }

    @Override
    public void render() {
        game.batch.draw(levelBackground, 0, 16);
        level.render(0, 16);

        pacman.render(game.batch, 0, 16);

        game.assets.getFont().draw(game.batch, "" + score, 25, 276);
    }

    @Override
    public void update(float dt) {
        pacman.update(dt);
    }

    @Override
    public void dispose() {
        Gdx.input.setInputProcessor(null);
    }

    public void eatPellet(float x, float y) {
        level.setTile(x, y, LevelTile.EMPTY);
        if (pelletEatenCount % 2 == 0) {
            game.assets.chomp_1.play(1.0f);
        } else {
            game.assets.chomp_2.play(1.0f);
        }
        pelletEatenCount++;
        pelletCount--;
        score += 10;
    }

    private final class Controller extends InputAdapter {

        @Override
        public boolean keyDown(int keycode) {
            switch (keycode) {
                case Input.Keys.UP:
                    pacman.nextDirection = MovableEntity.Direction.NORTH;
                    break;
                case Input.Keys.DOWN:
                    pacman.nextDirection = MovableEntity.Direction.SOUTH;
                    break;
                case Input.Keys.LEFT:
                    pacman.nextDirection = MovableEntity.Direction.WEST;
                    break;
                case Input.Keys.RIGHT:
                    pacman.nextDirection = MovableEntity.Direction.EAST;
                    break;
            }
            return super.keyDown(keycode);
        }

    }

}
